# Copyright (C) 2023 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
import pydantic


class PublicIdentifier(pydantic.BaseModel):
    """Like :mod:`~headless.ext.oauth2.ExternalIdentifier`, but this
    identifier is known to be a *public* identifier.
    """
    __module__: str = 'cbra.core.iam.types'
    iss: str
    sub: str